package cn.knero.permission.manager;

import android.app.Activity;
import android.app.FragmentManager;
import android.os.Build;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by luozhaocheng on 29/12/2016.
 */

public class PermissionManager {

    private static final String PACKAGE_NAME = "cn.knero.permission.manager";

    private static final String FRAGMENT_TAG = PACKAGE_NAME + "permission.fragment.tag";
    private PermissionManagerFragment mPermissionManagerFragment;

    private String mFragmentTag = FRAGMENT_TAG;

    public PermissionManager(Activity activity) {
        mPermissionManagerFragment = getPermissionManagerFragment(activity);
    }


    public PermissionManager(Activity activity, String fragmentTag) {
        this.mFragmentTag = fragmentTag;
        this.mPermissionManagerFragment = getPermissionManagerFragment(activity);
    }

    private PermissionManagerFragment getPermissionManagerFragment(Activity activity) {
        FragmentManager fragmentManager = activity.getFragmentManager();
        PermissionManagerFragment fragment = (PermissionManagerFragment) fragmentManager.findFragmentByTag(mFragmentTag);
        if (fragment == null) {
            fragment = new PermissionManagerFragment();
            fragmentManager.beginTransaction().add(fragment, mFragmentTag).commit();
            fragmentManager.executePendingTransactions();
        }
        return fragment;
    }

    public void requestPermission(RequestPermissionCallback callback, final String... permissions) {
        mPermissionManagerFragment.setCallback(callback);
        List<String> unRequestPermission = new ArrayList<>();
        for (String permission : permissions) {
            Log.d("TAG", "requesting permission:" + permission);
            if (isGranted(permission)) {
                Permission p = new Permission(permission, true, false);
                mPermissionManagerFragment.setPermission(permission, p);
                continue;
            }
            Permission p = mPermissionManagerFragment.getPermission(permission);
            if (p == null) {
                unRequestPermission.add(permission);
                p = new Permission(permission, false);
                mPermissionManagerFragment.setPermission(permission, p);
            }
        }
        if (!unRequestPermission.isEmpty()) {
            String[] unrequestedPermissionsArray = unRequestPermission.toArray(new String[unRequestPermission.size()]);
            mPermissionManagerFragment.requestPermissions(unrequestedPermissionsArray);
        }
    }

    public boolean isGranted(String permission) {
        return !isMarshmallow() || mPermissionManagerFragment.isGranted(permission);
    }

    public boolean isRevoked(String permission) {
        return isMarshmallow() && mPermissionManagerFragment.isRevoked(permission);
    }

    boolean isMarshmallow() {
        return Build.VERSION.SDK_INT >= Build.VERSION_CODES.M;
    }

}
