package cn.knero.permission.manager;


import android.annotation.TargetApi;
import android.app.Fragment;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;

import java.util.HashMap;
import java.util.Map;


/**
 * Created by luozhaocheng on 29/12/2016.
 */

public class PermissionManagerFragment extends Fragment {

    private static final int PERMISSIONS_REQUEST_CODE = 100;
    private Map<String, Permission> mAllPermissions = new HashMap<>();
    private RequestPermissionCallback mCallback;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setRetainInstance(true);
    }

    @TargetApi(Build.VERSION_CODES.M)
    void requestPermissions(String[] permissions) {
        requestPermissions(permissions, PERMISSIONS_REQUEST_CODE);
    }

    @Override
    @TargetApi(Build.VERSION_CODES.M)
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode != PERMISSIONS_REQUEST_CODE) return;
        boolean[] shouldShowRequestPermissionRationale = new boolean[permissions.length];
        for (int i = 0; i < permissions.length; i++) {
            shouldShowRequestPermissionRationale[i] = shouldShowRequestPermissionRationale(permissions[i]);
        }
        onRequestPermissionsResult(permissions, grantResults, shouldShowRequestPermissionRationale);
    }

    void onRequestPermissionsResult(String permissions[], int[] grantResults, boolean[] shouldShowRequestPermissionRationale) {
        for (int i = 0, size = permissions.length; i < size; i++) {
            // Find the corresponding subject
            Permission permission = mAllPermissions.get(permissions[i]);
            if (permission == null) {
                // No subject found
                Log.e("PermissionManager", "PermissionManager.onRequestPermissionsResult invoked but didn't find the corresponding permission request.");
                return;
            }
            boolean granted = grantResults[i] == PackageManager.PERMISSION_GRANTED;
            permission.granted = granted;
            permission.shouldShowRequestPermissionRationale = shouldShowRequestPermissionRationale[i];
        }
        if (mCallback != null) {
            mCallback.onCallback(mAllPermissions);
        }
    }

    public void setCallback(RequestPermissionCallback callback) {
        mCallback = callback;
    }

    /**
     * 判断是不是授权
     */
    @TargetApi(Build.VERSION_CODES.M)
    boolean isGranted(String permission) {
        return getActivity().checkSelfPermission(permission) == PackageManager.PERMISSION_GRANTED;
    }

    /**
     * 判断是不是在包中申明
     */
    @TargetApi(Build.VERSION_CODES.M)
    boolean isRevoked(String permission) {
        return getActivity().getPackageManager().isPermissionRevokedByPolicy(permission, getActivity().getPackageName());
    }

    public Permission getPermission(String permission) {
        return mAllPermissions.get(permission);
    }

    public Permission setPermission(String permission, Permission subject) {
        return mAllPermissions.put(permission, subject);
    }
}
