package cn.knero.file.permission.file_permission_manager

import android.Manifest
import androidx.annotation.IntDef
import cn.knero.permission.manager.PermissionManager
import cn.knero.permission.manager.RequestPermissionCallback
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class FilePermissionManagerPlugin(registrar: Registrar) : MethodCallHandler {


    @IntDef(PERMISSION_STATUS_DENIED, PERMISSION_STATUS_DISABLED, PERMISSION_STATUS_GRANTED, PERMISSION_STATUS_RESTRICTED, PERMISSION_STATUS_UNKNOWN)
    private annotation class PermissionStatus

    private val mPermissionmanager: PermissionManager = PermissionManager(registrar.activity())

    companion object {
        private const val PERMISSION_STATUS_DENIED = 0
        private const val PERMISSION_STATUS_DISABLED = 1
        private const val PERMISSION_STATUS_GRANTED = 2
        private const val PERMISSION_STATUS_RESTRICTED = 3
        private const val PERMISSION_STATUS_UNKNOWN = 4
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "cn.knero.file.permission.manager")
            channel.setMethodCallHandler(FilePermissionManagerPlugin(registrar))
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when {
            call.method == "checkPermissionStatus" -> {
                val permissionStatus = checkPermissionStatus()
                result.success(permissionStatus)
            }
            call.method == "requestPermissions" -> {
                requestPermissions(result)
            }
            else -> result.notImplemented()
        }
    }

    @PermissionStatus
    private fun checkPermissionStatus(): Int {
        val result = mPermissionmanager.isGranted(Manifest.permission.WRITE_EXTERNAL_STORAGE)
        return if (result) PERMISSION_STATUS_GRANTED else return PERMISSION_STATUS_DENIED
    }

    private fun requestPermissions(result: Result) {
        mPermissionmanager.requestPermission(RequestPermissionCallback {
            val permission = it[Manifest.permission.WRITE_EXTERNAL_STORAGE]
            if (permission!!.granted) {
                result.success(PERMISSION_STATUS_GRANTED)
            } else {
                result.success(PERMISSION_STATUS_DISABLED)
            }
        }, Manifest.permission.WRITE_EXTERNAL_STORAGE)
    }
}
