import 'dart:async';
import 'dart:io';

import 'package:flutter/services.dart';

import 'permission_state.dart';

class FilePermissionHandler {
  factory FilePermissionHandler() {
    if (_instance == null) {
      const MethodChannel methodChannel =
          MethodChannel('cn.knero.file.permission.manager');

      _instance = FilePermissionHandler.private(methodChannel);
    }
    return _instance;
  }

  static FilePermissionHandler _instance;
  final MethodChannel _methodChannel;

  FilePermissionHandler.private(this._methodChannel);

  Future<PermissionStatus> hasFileSystemPermission() async {
    if (!Platform.isAndroid) {
      return PermissionStatus.disabled;
    }
    final int status =
        await _methodChannel.invokeMethod('checkPermissionStatus');

    return Codec.decodePermissionStatus(status);
  }

  Future requestFileSystemPermission() async {
    int state = await _methodChannel.invokeMethod("requestPermissions");
    return Codec.decodePermissionStatus(state);
  }
}
